pub enum IfcType {
Show 231 variants
IfcProject,
IfcSite,
IfcBuilding,
IfcBuildingStorey,
IfcSpace,
IfcWall,
IfcWallStandardCase,
IfcCurtainWall,
IfcSlab,
IfcRoof,
IfcBeam,
IfcColumn,
IfcDoor,
IfcWindow,
IfcStair,
IfcStairFlight,
IfcRamp,
IfcRampFlight,
IfcRailing,
IfcCovering,
IfcPlate,
IfcMember,
IfcFooting,
IfcPile,
IfcBuildingElementProxy,
IfcElementAssembly,
IfcDistributionElement,
IfcDistributionFlowElement,
IfcFlowTerminal,
IfcFlowSegment,
IfcFlowFitting,
IfcFlowController,
IfcFlowMovingDevice,
IfcFlowStorageDevice,
IfcFlowTreatmentDevice,
IfcEnergyConversionDevice,
IfcDistributionControlElement,
IfcFurnishingElement,
IfcFurniture,
IfcSystemFurnitureElement,
IfcOpeningElement,
IfcOpeningStandardCase,
IfcVoidingFeature,
IfcProjectionElement,
IfcExtrudedAreaSolid,
IfcExtrudedAreaSolidTapered,
IfcRevolvedAreaSolid,
IfcRevolvedAreaSolidTapered,
IfcSweptDiskSolid,
IfcSweptDiskSolidPolygonal,
IfcSurfaceCurveSweptAreaSolid,
IfcFixedReferenceSweptAreaSolid,
IfcFacetedBrep,
IfcFacetedBrepWithVoids,
IfcAdvancedBrep,
IfcAdvancedBrepWithVoids,
IfcTriangulatedFaceSet,
IfcPolygonalFaceSet,
IfcTessellatedFaceSet,
IfcBooleanResult,
IfcBooleanClippingResult,
IfcMappedItem,
IfcRepresentationMap,
IfcBlock,
IfcRectangularPyramid,
IfcRightCircularCone,
IfcRightCircularCylinder,
IfcSphere,
IfcHalfSpaceSolid,
IfcPolygonalBoundedHalfSpace,
IfcBoxedHalfSpace,
IfcArbitraryClosedProfileDef,
IfcArbitraryProfileDefWithVoids,
IfcRectangleProfileDef,
IfcRectangleHollowProfileDef,
IfcCircleProfileDef,
IfcCircleHollowProfileDef,
IfcEllipseProfileDef,
IfcIShapeProfileDef,
IfcLShapeProfileDef,
IfcTShapeProfileDef,
IfcUShapeProfileDef,
IfcCShapeProfileDef,
IfcZShapeProfileDef,
IfcAsymmetricIShapeProfileDef,
IfcTrapeziumProfileDef,
IfcCompositeProfileDef,
IfcDerivedProfileDef,
IfcCenterLineProfileDef,
IfcPolyline,
IfcCompositeCurve,
IfcCompositeCurveSegment,
IfcTrimmedCurve,
IfcCircle,
IfcEllipse,
IfcLine,
IfcBSplineCurve,
IfcBSplineCurveWithKnots,
IfcRationalBSplineCurveWithKnots,
IfcIndexedPolyCurve,
IfcPlane,
IfcCurveBoundedPlane,
IfcCylindricalSurface,
IfcBSplineSurface,
IfcBSplineSurfaceWithKnots,
IfcRationalBSplineSurfaceWithKnots,
IfcCartesianPoint,
IfcDirection,
IfcVector,
IfcCartesianPointList2D,
IfcCartesianPointList3D,
IfcAxis2Placement2D,
IfcAxis2Placement3D,
IfcLocalPlacement,
IfcCartesianTransformationOperator3D,
IfcCartesianTransformationOperator3DnonUniform,
IfcShapeRepresentation,
IfcProductDefinitionShape,
IfcGeometricRepresentationContext,
IfcGeometricRepresentationSubContext,
IfcClosedShell,
IfcOpenShell,
IfcFace,
IfcFaceBound,
IfcFaceOuterBound,
IfcPolyLoop,
IfcEdgeLoop,
IfcOrientedEdge,
IfcEdgeCurve,
IfcVertexPoint,
IfcConnectedFaceSet,
IfcRelContainedInSpatialStructure,
IfcRelAggregates,
IfcRelDefinesByProperties,
IfcRelDefinesByType,
IfcRelAssociatesMaterial,
IfcRelVoidsElement,
IfcRelFillsElement,
IfcRelConnectsPathElements,
IfcRelSpaceBoundary,
IfcRelAssignsToGroup,
IfcPropertySet,
IfcPropertySingleValue,
IfcPropertyEnumeratedValue,
IfcPropertyBoundedValue,
IfcPropertyListValue,
IfcPropertyTableValue,
IfcComplexProperty,
IfcElementQuantity,
IfcQuantityLength,
IfcQuantityArea,
IfcQuantityVolume,
IfcQuantityCount,
IfcQuantityWeight,
IfcQuantityTime,
IfcMaterial,
IfcMaterialLayer,
IfcMaterialLayerSet,
IfcMaterialLayerSetUsage,
IfcMaterialList,
IfcMaterialConstituentSet,
IfcMaterialConstituent,
IfcMaterialProfile,
IfcMaterialProfileSet,
IfcMaterialProfileSetUsage,
IfcStyledItem,
IfcSurfaceStyle,
IfcSurfaceStyleRendering,
IfcColourRgb,
IfcPresentationLayerAssignment,
IfcLightFixture,
IfcLightFixtureType,
IfcLightSource,
IfcLightSourceAmbient,
IfcLightSourceDirectional,
IfcLightSourceGoniometric,
IfcLightSourcePositional,
IfcLightSourceSpot,
IfcLightIntensityDistribution,
IfcLightDistributionData,
IfcUnitAssignment,
IfcSIUnit,
IfcConversionBasedUnit,
IfcDerivedUnit,
IfcMeasureWithUnit,
IfcWallType,
IfcSlabType,
IfcBeamType,
IfcColumnType,
IfcDoorType,
IfcWindowType,
IfcCoveringType,
IfcRailingType,
IfcStairType,
IfcStairFlightType,
IfcRampType,
IfcRampFlightType,
IfcRoofType,
IfcMemberType,
IfcPlateType,
IfcFootingType,
IfcPileType,
IfcBuildingElementProxyType,
IfcAlignment,
IfcAlignmentCant,
IfcAlignmentHorizontal,
IfcAlignmentVertical,
IfcAlignmentSegment,
IfcRoad,
IfcRoadPart,
IfcBridge,
IfcBridgePart,
IfcRailway,
IfcRailwayPart,
IfcFacility,
IfcFacilityPart,
IfcGeotechnicalElement,
IfcBorehole,
IfcGeomodel,
IfcGeoslice,
IfcSolidStratum,
IfcVoidStratum,
IfcWaterStratum,
IfcEarthworksCut,
IfcEarthworksFill,
IfcEarthworksElement,
IfcPavement,
IfcCourse,
IfcKerb,
IfcDeepFoundation,
Unknown(String),
}Expand description
IFC entity type enumeration
Covers all common IFC entity types. Unknown types are captured with their original string representation.
Variants
IfcProject
IfcSite
IfcBuilding
IfcBuildingStorey
IfcSpace
IfcWall
IfcWallStandardCase
IfcCurtainWall
IfcSlab
IfcRoof
IfcBeam
IfcColumn
IfcDoor
IfcWindow
IfcStair
IfcStairFlight
IfcRamp
IfcRampFlight
IfcRailing
IfcCovering
IfcPlate
IfcMember
IfcFooting
IfcPile
IfcBuildingElementProxy
IfcElementAssembly
IfcDistributionElement
IfcDistributionFlowElement
IfcFlowTerminal
IfcFlowSegment
IfcFlowFitting
IfcFlowController
IfcFlowMovingDevice
IfcFlowStorageDevice
IfcFlowTreatmentDevice
IfcEnergyConversionDevice
IfcDistributionControlElement
IfcFurnishingElement
IfcFurniture
IfcSystemFurnitureElement
IfcOpeningElement
IfcOpeningStandardCase
IfcVoidingFeature
IfcProjectionElement
IfcExtrudedAreaSolid
IfcExtrudedAreaSolidTapered
IfcRevolvedAreaSolid
IfcRevolvedAreaSolidTapered
IfcSweptDiskSolid
IfcSweptDiskSolidPolygonal
IfcSurfaceCurveSweptAreaSolid
IfcFixedReferenceSweptAreaSolid
IfcFacetedBrep
IfcFacetedBrepWithVoids
IfcAdvancedBrep
IfcAdvancedBrepWithVoids
IfcTriangulatedFaceSet
IfcPolygonalFaceSet
IfcTessellatedFaceSet
IfcBooleanResult
IfcBooleanClippingResult
IfcMappedItem
IfcRepresentationMap
IfcBlock
IfcRectangularPyramid
IfcRightCircularCone
IfcRightCircularCylinder
IfcSphere
IfcHalfSpaceSolid
IfcPolygonalBoundedHalfSpace
IfcBoxedHalfSpace
IfcArbitraryClosedProfileDef
IfcArbitraryProfileDefWithVoids
IfcRectangleProfileDef
IfcRectangleHollowProfileDef
IfcCircleProfileDef
IfcCircleHollowProfileDef
IfcEllipseProfileDef
IfcIShapeProfileDef
IfcLShapeProfileDef
IfcTShapeProfileDef
IfcUShapeProfileDef
IfcCShapeProfileDef
IfcZShapeProfileDef
IfcAsymmetricIShapeProfileDef
IfcTrapeziumProfileDef
IfcCompositeProfileDef
IfcDerivedProfileDef
IfcCenterLineProfileDef
IfcPolyline
IfcCompositeCurve
IfcCompositeCurveSegment
IfcTrimmedCurve
IfcCircle
IfcEllipse
IfcLine
IfcBSplineCurve
IfcBSplineCurveWithKnots
IfcRationalBSplineCurveWithKnots
IfcIndexedPolyCurve
IfcPlane
IfcCurveBoundedPlane
IfcCylindricalSurface
IfcBSplineSurface
IfcBSplineSurfaceWithKnots
IfcRationalBSplineSurfaceWithKnots
IfcCartesianPoint
IfcDirection
IfcVector
IfcCartesianPointList2D
IfcCartesianPointList3D
IfcAxis2Placement2D
IfcAxis2Placement3D
IfcLocalPlacement
IfcCartesianTransformationOperator3D
IfcCartesianTransformationOperator3DnonUniform
IfcShapeRepresentation
IfcProductDefinitionShape
IfcGeometricRepresentationContext
IfcGeometricRepresentationSubContext
IfcClosedShell
IfcOpenShell
IfcFace
IfcFaceBound
IfcFaceOuterBound
IfcPolyLoop
IfcEdgeLoop
IfcOrientedEdge
IfcEdgeCurve
IfcVertexPoint
IfcConnectedFaceSet
IfcRelContainedInSpatialStructure
IfcRelAggregates
IfcRelDefinesByProperties
IfcRelDefinesByType
IfcRelAssociatesMaterial
IfcRelVoidsElement
IfcRelFillsElement
IfcRelConnectsPathElements
IfcRelSpaceBoundary
IfcRelAssignsToGroup
IfcPropertySet
IfcPropertySingleValue
IfcPropertyEnumeratedValue
IfcPropertyBoundedValue
IfcPropertyListValue
IfcPropertyTableValue
IfcComplexProperty
IfcElementQuantity
IfcQuantityLength
IfcQuantityArea
IfcQuantityVolume
IfcQuantityCount
IfcQuantityWeight
IfcQuantityTime
IfcMaterial
IfcMaterialLayer
IfcMaterialLayerSet
IfcMaterialLayerSetUsage
IfcMaterialList
IfcMaterialConstituentSet
IfcMaterialConstituent
IfcMaterialProfile
IfcMaterialProfileSet
IfcMaterialProfileSetUsage
IfcStyledItem
IfcSurfaceStyle
IfcSurfaceStyleRendering
IfcColourRgb
IfcPresentationLayerAssignment
IfcLightFixture
IfcLightFixtureType
IfcLightSource
IfcLightSourceAmbient
IfcLightSourceDirectional
IfcLightSourceGoniometric
IfcLightSourcePositional
IfcLightSourceSpot
IfcLightIntensityDistribution
IfcLightDistributionData
IfcUnitAssignment
IfcSIUnit
IfcConversionBasedUnit
IfcDerivedUnit
IfcMeasureWithUnit
IfcWallType
IfcSlabType
IfcBeamType
IfcColumnType
IfcDoorType
IfcWindowType
IfcCoveringType
IfcRailingType
IfcStairType
IfcStairFlightType
IfcRampType
IfcRampFlightType
IfcRoofType
IfcMemberType
IfcPlateType
IfcFootingType
IfcPileType
IfcBuildingElementProxyType
IfcAlignment
IfcAlignmentCant
IfcAlignmentHorizontal
IfcAlignmentVertical
IfcAlignmentSegment
IfcRoad
IfcRoadPart
IfcBridge
IfcBridgePart
IfcRailway
IfcRailwayPart
IfcFacility
IfcFacilityPart
IfcGeotechnicalElement
IfcBorehole
IfcGeomodel
IfcGeoslice
IfcSolidStratum
IfcVoidStratum
IfcWaterStratum
IfcEarthworksCut
IfcEarthworksFill
IfcEarthworksElement
IfcPavement
IfcCourse
IfcKerb
IfcDeepFoundation
Unknown(String)
Unknown type - stores the original type name string
Implementations
Sourceimpl IfcType
impl IfcType
Sourcepub fn has_geometry(&self) -> bool
pub fn has_geometry(&self) -> bool
Check if this type represents a building element with potential geometry
Sourcepub fn is_spatial(&self) -> bool
pub fn is_spatial(&self) -> bool
Check if this type is a spatial structure element